@@ -5,7 +5,7 @@
 
 #include "lilv_test_utils.h"
 
-#include "lilv/lilv.h"
+#include <lilv/lilv.h>
 
 #include <assert.h>
 #include <stdint.h>
@@ -25,8 +25,8 @@ static const char* const plugin_ttl = "\
 int
 main(void)
 {
-  LilvTestEnv* const env   = lilv_test_env_new();
-  LilvWorld* const   world = env->world;
+  LilvTestEnv* const     env   = lilv_test_env_new();
+  const LilvWorld* const world = env->world;
 
   if (create_bundle(
         env, "bad_port_index.lv2", SIMPLE_MANIFEST_TTL, plugin_ttl)) {
